from setuptools import find_packages, setup

with open("app/Readme.md", "r") as f:
    long_description = f.read()

setup(
    name="ytcomment",
    version="0.0.1",
    description="ytcomment scrap all comments and title given a  youtube url.",
    package_dir={"": "app"},
    packages=find_packages(where="app"),
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/azerinho007/",
    author="Azer",
    author_email="azerch.1996@gmail.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3.7",
        "Operating System :: OS Independent",
    ],
    install_requires=["google-api-python-client>=2.81.0"],
    extras_require={
        "dev": ["twine>=4.0.2"],
    },
    python_requires=">=3.7",
)


import requests
import json
import googleapiclient.discovery



GOOGLE_KEY = "AIzaSyBZdHYAp2WWgm413pasORoGG2nJ179DYVg"
MAX_COMMENT = 10000

def youtubescrapper(link):

    api_service_name = "youtube"
    api_version = "v3"

    youtube = googleapiclient.discovery.build(
        api_service_name, api_version, developerKey=GOOGLE_KEY)
    try:
        video_id = link.split("v=")[-1]
        video_id = video_id.split("&")[0]
        request = youtube.videos().list(
            part="snippet",
            id=video_id
        )
        resposne = request.execute()
        title = resposne["items"][0]["snippet"]["title"]
    except Exception as err:
        print(str(err))
        return ["Please provide a correct youtube video"], None

    comments = []
    flag = 1
    next_page = None
    while flag:
        try:
            if next_page:
                request = youtube.commentThreads().list(
                    part="snippet,replies",
                    pageToken=next_page,
                    videoId = video_id
                )
            else:
                request = youtube.commentThreads().list(
                    part="snippet,replies",
                    videoId = video_id
                )
            res = request.execute()
            next_page = res.get("nextPageToken")
            count = 0
            for item in res["items"]:
                try:
                    iii = comments.index(item["snippet"]["topLevelComment"]["snippet"]["textOriginal"])
                    count += 1
                except:
                    comments.append(item["snippet"]["topLevelComment"]["snippet"]["textOriginal"])
            if count == len(res["items"]) or len(comments) >= MAX_COMMENT:
                flag = 0
        except:
            comments= ["No comments Available"]

    return comments, title

